package com.jjt.calc.service;

import java.util.List;
import com.jjt.calc.domain.TwinPanHeadInfo;

/**
 * 设备盘头信息Service接口
 *
 * @author wukai
 * @date 2025-01-18
 */
public interface ITwinPanHeadInfoService {
    /**
     * 查询设备盘头信息
     *
     * @param infoId 设备盘头信息主键
     * @return 设备盘头信息
     */
    public TwinPanHeadInfo selectTwinPanHeadInfoByInfoId(Long infoId);

    /**
     * 查询设备盘头信息列表
     *
     * @param twinPanHeadInfo 设备盘头信息
     * @return 设备盘头信息集合
     */
    public List<TwinPanHeadInfo> selectTwinPanHeadInfoList(TwinPanHeadInfo twinPanHeadInfo);

    /**
     * 新增设备盘头信息
     *
     * @param twinPanHeadInfo 设备盘头信息
     * @return 结果
     */
    public int insertTwinPanHeadInfo(TwinPanHeadInfo twinPanHeadInfo);

    /**
     * 修改设备盘头信息
     *
     * @param twinPanHeadInfo 设备盘头信息
     * @return 结果
     */
    public int updateTwinPanHeadInfo(TwinPanHeadInfo twinPanHeadInfo);

    /**
     * 批量删除设备盘头信息
     *
     * @param infoIds 需要删除的设备盘头信息主键集合
     * @return 结果
     */
    public int deleteTwinPanHeadInfoByInfoIds(Long[] infoIds);

    /**
     * 删除设备盘头信息信息
     *
     * @param infoId 设备盘头信息主键
     * @return 结果
     */
    public int deleteTwinPanHeadInfoByInfoId(Long infoId);
}
